Examples
==========

Here there is a small number of small examples to get you going with SatMAD. You can find the interactive
Jupyter notebook versions of these at the
`project repository <https://github.com/egemenimre/satmad/tree/master/docs/examples>`_.

In addition to the examples in this section, there is a repository of tutorials, how-to guides
and analyses in a dedicated project called SatMAD Applications,
`available at Github <https://github.com/egemenimre/satmad_applications>`_ (for Jupyter notebooks)
and `in plain document format <https://satmad-applications.readthedocs.io/>`_.


Tutorials
---------
.. toctree::
    :maxdepth: 1

    examples/tutorials/satmad_first_steps.ipynb
    examples/tutorials/sso_analysis.ipynb
